==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleProvidersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConsoleProvidersFluent<A extends io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildStatuspage instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.StatuspageProvider getStatuspage();
  public io.fabric8.openshift.api.model.operator.v1.StatuspageProvider buildStatuspage();
  public A withStatuspage(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider statuspage);
  public java.lang.Boolean hasStatuspage();
  public A withNewStatuspage(java.lang.String pageID);
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspage();
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspageLike(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item);
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editStatuspage();
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspage();
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspageLike(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item);
  public interface StatuspageNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.StatuspageProviderFluent<io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<N>>{
    public N and();
    public N endStatuspage();
    
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleProvidersFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ConsoleProvidersFluent<A extends io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildStatuspage instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.StatuspageProvider getStatuspage();
  public io.fabric8.openshift.api.model.operator.v1.StatuspageProvider buildStatuspage();
  public A withStatuspage(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider statuspage);
  public java.lang.Boolean hasStatuspage();
  public A withNewStatuspage(java.lang.String pageID);
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspage();
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspageLike(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item);
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editStatuspage();
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspage();
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspageLike(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface StatuspageNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.StatuspageProviderFluent<io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<N>>{
    public N and();
    public N endStatuspage();
    
  }
  
}
